package App::PDRUtils::DistIniCmd;

our $DATE = '2016-03-03'; # DATE
our $VERSION = '0.04'; # VERSION

use 5.010001;
use strict;
use warnings;

our %common_args = (
    #dist_ini => {
    #    schema => 'str*',
    #    req => 1,
    #},
    parsed_dist_ini => {
        schema => ['obj*'],
        req => 1,
    },
);

1;
# ABSTRACT: Common stuffs for App::PDRUtils::DistIniCmd::*

__END__

=pod

=encoding UTF-8

=head1 NAME

App::PDRUtils::DistIniCmd - Common stuffs for App::PDRUtils::DistIniCmd::*

=head1 VERSION

This document describes version 0.04 of App::PDRUtils::DistIniCmd (from Perl distribution App-PDRUtils), released on 2016-03-03.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-PDRUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-PDRUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-PDRUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
